# Semantic {Component}

This repository contains pre-compiled {component} files using the default themes. This is intended for use in projects that do not need all the bells and whistles of Semantic UI, and want to keep file size to a minimum.

For the latest changes please see the [Release Notes](https://github.com/Semantic-Org/UI-{Component}/blob/master/RELEASE-NOTES.md)

**Special Note**
An update in `2.0.8` has fixed an issue which may have prevented some single component modules from working correctly. Please see notes in [this pull request](https://github.com/Semantic-Org/Semantic-UI/pull/2816).

If you're looking for the full version of Semantic including all components and build tools [check out the main project repository](https://github.com/Semantic-Org/Semantic-UI/tree/1.0)

#### To install with Bower
```
bower install semantic-ui-{component}
```

#### To install with NPM
```
npm install semantic-ui-{component}
```

#### To install with Meteor
```
meteor add semantic:ui-{component}
```


## Addendum

This element's definitions (required class names, html structures) are available in the [UI Docs](http://www.semantic-ui.com)

Please consider checking out [all the benefits to theming](http://www.learnsemantic.com/guide/expert.html) before using these stand-alone releases.
